@@ -41,7 +41,7 @@ RangeDefinition = Union[
 class SliderKwargs(abc.Mapping):
     """Wrapper around a `dict` of sliders that can serve as keyword arguments.
 
-    Sliders can be defined in `mpl_interactions.interactive_plot` through
+    Sliders can be defined in :func:`mpl_interactions.interactive_plot` through
     :term:`kwargs <python:keyword argument>`. This wrapper class can be used
     for that.
     """
